@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Check the configuration of an application
 
 package App::Cme::Command::check ;
-$App::Cme::Command::check::VERSION = '1.015';
+$App::Cme::Command::check::VERSION = '1.026';
 use strict;
 use warnings;
 use 5.10.1;
@@ -22,13 +22,17 @@ use base qw/App::Cme::Common/;
 use Config::Model::ObjTreeScanner;
 
 sub validate_args {
-    shift->process_args(@_);
+    my ($self, $opt, $args) = @_;
+
+    $self->check_unknown_args($args);
+    $self->process_args($opt,$args);
 }
 
 sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "strict!" => "cme will exit 1 if warnings are found during check" ],
+        [ "quiet!"  => "Suppress progress messages" ],
         $class->cme_global_options,
     );
 }
@@ -36,7 +40,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application]  [ config_file | ~~ ]";
+  return "$desc [application]  [ config_file ]";
 }
 
 sub description {
@@ -48,9 +52,14 @@ sub execute {
     my ($self, $opt, $args) = @_;
 
     my ($model, $inst, $root) = $self->init_cme($opt,$args);
-
+    my $check =  $opt->{force_load} ? 'no' : 'yes' ;
     say "loading data" unless $opt->{quiet};
-    Config::Model::ObjTreeScanner->new( leaf_cb => sub { } )->scan_node( undef, $root );
+
+    Config::Model::ObjTreeScanner->new(
+        leaf_cb => sub { },
+        check => $check,
+    )->scan_node( undef, $root );
+
     say "checking data" unless $opt->{quiet};
     $root->dump_tree( mode => 'full' ); # light check (value per value)
     $root->deep_check; # consistency check
@@ -79,7 +88,7 @@ App::Cme::Command::check - Check the configuration of an application
 
 =head1 VERSION
 
-version 1.015
+version 1.026
 
 =head1 SYNOPSIS
 
@@ -139,7 +148,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
