@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Dump the configuration of an application
 
 package App::Cme::Command::dump ;
-$App::Cme::Command::dump::VERSION = '1.016';
+$App::Cme::Command::dump::VERSION = '1.026';
 use strict;
 use warnings;
 use 5.10.1;
@@ -26,6 +26,7 @@ use Data::Dumper;
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
+    $self->check_unknown_args($args);
     $opt->{quiet} = 1; # don't want to mess up yaml output
     $self->process_args($opt,$args);
 }
@@ -36,14 +37,14 @@ sub opt_spec {
         [
             "dumptype=s" => "Dump all values (full) or only customized values",
             {
-                regex => qr/^(?:full|custom)$/,
+                regex => qr/^(?:full|custom|non_upstream_default)$/,
                 default => 'custom'
             }
         ],
         [
             "format=s" => "dump using specified format",
             {
-                regex => qr/^(?:json|yaml|perl|cml)$/,
+                regex => qr/^(?:json|ya?ml|perl|cml|cds)$/i,
                 default => 'yaml'
             },
         ],
@@ -55,7 +56,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application]  [ config_file | ~~ ] [ -dumptype full|custom ] [ path ]";
+  return "$desc [application]  [ config_file ] [ -dumptype full|custom ] [ path ]";
 }
 
 sub description {
@@ -72,9 +73,9 @@ sub execute {
 
     my $dump_string;
     my $format = $opt->{format};
-    my $mode = $opt->{dumptype} eq 'full' ? 'non_upstream_default' : 'custom';
+    my $mode = $opt->{dumptype} || 'custom';
 
-    if ($format eq 'cml') {
+    if ($format =~ /cml|cds/i) {
         $dump_string = $target_node->dump_tree( mode => $mode );
     }
     else {
@@ -82,9 +83,10 @@ sub execute {
             ordered_hash_as_list => 0,
             mode => $mode
         );
-        $dump_string = $format eq 'yaml' ? Dump($perl_data)
-            : $format eq 'JSON' ? encode_json($perl_data)
-            :                     Dumper($perl_data) ;
+        $dump_string
+            = $format =~ /ya?ml/i ? Dump($perl_data)
+            : $format =~ /json/i  ? encode_json($perl_data)
+            :                       Dumper($perl_data) ; # Perl data structure
     }
     print $dump_string ;
 }
@@ -103,7 +105,7 @@ App::Cme::Command::dump - Dump the configuration of an application
 
 =head1 VERSION
 
-version 1.016
+version 1.026
 
 =head1 SYNOPSIS
 
@@ -122,12 +124,16 @@ By default, dump only custom values, i.e. different from application
 built-in values or model default values. You can use the C<-dumptype> option for
 other types of dump:
 
- -dumptype [ full | custom ]
+ -dumptype [ full | custom | non_upstream_default ]
 
-Choose to dump every values (full) or only customized values (default)
+Choose to dump every values (full), or only customized values (default)
 
-By default, dump in yaml format. This can be changed in C<JSON>,
-C<Perl>, C<cml> (aka L<Config::Model::Loader> format).
+C<non_upstream_default> is like C<full> mode, but value identical with
+application default are omitted. But this should seldom happen.
+
+By default, dump in yaml format. This can be changed in C<json>,
+C<perl>, C<cml> (aka L<Config::Model::Loader> format, C<cds> is also
+accepted) with C<-format> option.
 
 =head1 Common options
 
@@ -143,7 +149,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
