@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Edit the configuration of an application
 
 package App::Cme::Command::edit ;
-$App::Cme::Command::edit::VERSION = '1.016';
+$App::Cme::Command::edit::VERSION = '1.026';
 use strict;
 use warnings;
 use 5.10.1;
@@ -23,6 +23,7 @@ use Config::Model::ObjTreeScanner;
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
+    $self->check_unknown_args($args);
     $self->process_args($opt,$args);
 }
 
@@ -30,6 +31,7 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return (
         [ "ui|if=s"     => "user interface type. Either tk, curses, shell" ],
+        [ "backup:s"  => "Create a backup of configuration files before saving." ],
         [ "open-item=s" => "open a specific item of the configuration" ],
         [ "quiet!"      => "Suppress progress messages" ],
         $class->cme_global_options,
@@ -57,9 +59,6 @@ sub execute {
     eval { require Config::Model::CursesUI; };
     my $has_curses = $@ ? 0 : 1;
 
-    eval { require Term::ReadLine; };
-    my $has_term_readline = $@ ? 0 : 1;
-
     my $ui_type = $opt->{ui};
 
     if ( not defined $ui_type ) {
@@ -70,29 +69,17 @@ sub execute {
             warn "You should install Config::Model::TkUI for a ", "more friendly user interface\n";
             $ui_type = 'curses';
         }
-        elsif ($has_term_readline) {
+        else {
             warn "You should install Config::Model::TkUI or ",
                 "Config::Model::CursesUI ",
                 "for a more friendly user interface\n";
             $ui_type = 'shell';
         }
-        else {
-            warn "You should install Config::Model::TkUI or ",
-                "Config::Model::CursesUI or Term::ReadLine",
-                "for a more friendly user interface\n";
-            $ui_type = 'simple';
-        }
     }
 
     $root->deep_check;
 
-    if ( $ui_type eq 'simple' ) {
-        require Config::Model::SimpleUI;
-        $self->run_shell_ui('Config::Model::SimpleUI', $inst) ;
-    }
-    elsif ( $ui_type eq 'shell' ) {
-        die "cannot run shell interface: ", "Term::ReadLine is not installed. Please use simple ui\n"
-            unless $has_term_readline;
+    if ( $ui_type eq 'shell' ) {
         require Config::Model::TermUI;
         $self->run_shell_ui('Config::Model::TermUI', $inst) ;
     }
@@ -138,7 +125,7 @@ App::Cme::Command::edit - Edit the configuration of an application
 
 =head1 VERSION
 
-version 1.016
+version 1.026
 
 =head1 SYNOPSIS
 
@@ -177,7 +164,7 @@ L<Config::Model::CursesUI> is installed).
 =item *
 
 C<shell>: provides a shell like interface.  See L<Config::Model::TermUI>
-for details.
+for details. This is equivalent to running C<cme shell> command.
 
 =back
 
@@ -193,6 +180,10 @@ See L<cme/"Global Options">.
 
 Open a specific item of the configuration when opening the editor
 
+=item -quiet
+
+Suppress porgress message
+
 =back
 
 =head1 SEE ALSO
@@ -205,7 +196,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
