@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Migrate the configuration of an application
 
 package App::Cme::Command::migrate ;
-$App::Cme::Command::migrate::VERSION = '1.010';
+$App::Cme::Command::migrate::VERSION = '1.026';
 use strict;
 use warnings;
 use 5.10.1;
@@ -23,12 +23,15 @@ use Config::Model::ObjTreeScanner;
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
+    $self->check_unknown_args($args);
     $self->process_args($opt,$args);
 }
 
 sub opt_spec {
     my ( $class, $app ) = @_;
     return (
+        [ "backup:s"  => "Create a backup of configuration files before saving." ],
+        [ "quiet!" => "Suppress progress messages" ],
         $class->cme_global_options,
     );
 }
@@ -36,7 +39,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application] [file | ~~ ]";
+  return "$desc [application] [file ]";
 }
 
 sub description {
@@ -68,7 +71,7 @@ App::Cme::Command::migrate - Migrate the configuration of an application
 
 =head1 VERSION
 
-version 1.010
+version 1.026
 
 =head1 SYNOPSIS
 
@@ -97,7 +100,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
