@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Search the configuration of an application
 
 package App::Cme::Command::search ;
-$App::Cme::Command::search::VERSION = '1.016';
+$App::Cme::Command::search::VERSION = '1.026';
 use strict;
 use warnings;
 use 5.10.1;
@@ -22,7 +22,9 @@ use base qw/App::Cme::Common/;
 use Config::Model::ObjTreeScanner;
 
 sub validate_args {
-    shift->process_args(@_);
+    my ($self, $opt, $args) = @_;
+    $self->check_unknown_args($args);
+    $self->process_args($opt,$args);
 }
 
 sub opt_spec {
@@ -44,7 +46,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application]  [ config_file | ~~ ] -search xxx [ -narrow-search ... ] " ;
+  return "$desc [application]  [ config_file ] -search xxx [ -narrow-search ... ] " ;
 }
 
 sub description {
@@ -84,7 +86,7 @@ App::Cme::Command::search - Search the configuration of an application
 
 =head1 VERSION
 
-version 1.016
+version 1.026
 
 =head1 SYNOPSIS
 
@@ -150,7 +152,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
