@@ -1,7 +1,7 @@
 #
 # This file is part of App-Cme
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2017 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -10,7 +10,7 @@
 # ABSTRACT: Update the configuration of an application
 
 package App::Cme::Command::update ;
-$App::Cme::Command::update::VERSION = '1.016';
+$App::Cme::Command::update::VERSION = '1.026';
 use strict;
 use warnings;
 use 5.10.1;
@@ -25,6 +25,7 @@ use Config::Model;
 
 sub validate_args {
     my ($self, $opt, $args) = @_;
+    $self->check_unknown_args($args);
     $self->process_args($opt,$args);
 }
 
@@ -32,7 +33,6 @@ sub opt_spec {
     my ( $class, $app ) = @_;
     return ( 
         [ "edit!"     => "Run editor after update is done" ],
-        [ "save!"     => "Force a save even if no change was done" ],
         [ "backup:s"  => "Create a backup of configuration files before saving." ],
         [ "quiet!"    => "Suppress progress messages" ],
         $class->cme_global_options,
@@ -42,7 +42,7 @@ sub opt_spec {
 sub usage_desc {
   my ($self) = @_;
   my $desc = $self->SUPER::usage_desc; # "%c COMMAND %o"
-  return "$desc [application] [file | ~~ ]";
+  return "$desc [application] [file ]";
 }
 
 sub description {
@@ -92,7 +92,7 @@ App::Cme::Command::update - Update the configuration of an application
 
 =head1 VERSION
 
-version 1.016
+version 1.026
 
 =head1 SYNOPSIS
 
@@ -132,7 +132,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Dominique Dumont.
+This software is Copyright (c) 2017 by Dominique Dumont.
 
 This is free software, licensed under:
 
